@@ -235,4 +235,13 @@ class Colour:
         """A factory method that returns a :class:`Colour` with a value of ``0x99aab5``."""
         return cls(0x99aab5)
 
+    @classmethod
+    def dark_theme(cls):
+        """A factory method that returns a :class:'Colour' with a value of ``0x36393F``.
+        Will appear transparent on Discord's dark theme and be the text colour on Discord's light theme.
+        
+        .. versionadded:: 1.5
+        """
+        return cls(0x36393F)
+
 Color = Colour
